#
# spec file for package libgdata
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Update baselibs.conf when changing this
%define _sover 22

Name:           libgdata
Version:        0.17.9
Release:        lp151.2.4
Summary:        GLib-based library for accessing online service APIs using the GData protocol
License:        LGPL-2.1+
Group:          Development/Libraries/GNOME
Url:            http://live.gnome.org/libgdata
Source:         https://download.gnome.org/sources/libgdata/0.17/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(gcr-base-3)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.14
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(goa-1.0) >= 3.8
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.15
# Note: as of 0.10.0, gtk+-3.0 is only needed to build a demo that isn't
# installed, so no need to depend on it
#BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.55.90
BuildRequires:  pkgconfig(libuhttpmock-0.0) >= 0.5.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(oauth)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libgdata is a GLib-based library for accessing online service APIs using
the GData protocol — most notably, Google's services. It provides APIs
to access the common Google services, and has full asynchronous support.

%package -n libgdata%{_sover}

Summary:        GLib-based library for accessing online service APIs using the GData protocol
Group:          System/Libraries
Recommends:     %{name}-lang
# Needed for the lang package to be installable:
Provides:       %{name} = %{version}

%description -n libgdata%{_sover}
libgdata is a GLib-based library for accessing online service APIs using
the GData protocol — most notably, Google's services. It provides APIs
to access the common Google services, and has full asynchronous support.

%package -n typelib-1_0-GData-0_0
Summary:        Introspection bindings for libgdata
Group:          System/Libraries

%description -n typelib-1_0-GData-0_0
libgdata is a GLib-based library for accessing online service APIs using
the GData protocol — most notably, Google's services. It provides APIs
to access the common Google services, and has full asynchronous support.

This package provides the GObject Introspection bindings for the
libgdata library.

%package devel
Summary:        Development files for libgdata, a library for accessing online service APIs
Group:          Development/Libraries/GNOME
Requires:       libgdata%{_sover} = %{version}
Requires:       typelib-1_0-GData-0_0 = %{version}

%description devel
libgdata is a GLib-based library for accessing online service APIs using
the GData protocol.

This subpackage contains the header files for developing
applications that want to make use of libgdata.


%lang_package
%prep
%setup -q
translation-update-upstream

%build
%configure \
	--disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang gdata

%post -n libgdata%{_sover} -p /sbin/ldconfig

%postun -n libgdata%{_sover} -p /sbin/ldconfig

%files -n libgdata%{_sover}
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING HACKING NEWS README
%{_libdir}/*.so.%{_sover}*

%files -n typelib-1_0-GData-0_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/GData-0.0.typelib

%files devel
%defattr(-,root,root)
%{_includedir}/libgdata/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libgdata.pc
%{_datadir}/gir-1.0/*.gir
%doc %{_datadir}/gtk-doc/html/gdata/

%files lang -f gdata.lang

%changelog
* Mon Sep 11 2017 jengelh@inai.de
- Replace old RPM macros and constructs by new equivalents.
- Update package descriptions.
* Wed Aug 23 2017 zaitor@opensuse.org
- Update to version 0.17.9:
  + Major changes:
  - Support reporting quotas for Drive usage.
  - Bump GLib dependency to 2.44 for g_autoptr() support.
  - Add g_autoptr() support for some core classes.
  - Port from GSimpleAsyncResult to GTask.
  - More porting to the Google Drive v2 API.
  + API changes:
  - Add GDataDocumentsMetadata.
  - Add gdata_documents_service_get_metadata(),
    gdata_documents_service_get_metadata_async(),
    gdata_documents_service_get_metadata_finish().
  - Initial g_autoptr() support for core classes.
  + Bugs fixed: bgo#783046, bgo#785885, bgo#684920.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 0.17.8:
  + Major changes:
  - Bump GLib dependency to 2.38.0 for G_TEST_DIST.
  - Bump libsoup dependency for tests to 2.55.90; the dependency
    if building libgdata without tests is still 2.42.0.
  - Fix use of deprecated GTK+ API in the demos.
  + Bugs fixed: bgo#779641, bgo#780067, bgo#780081.
  + Updated translations.
* Mon Mar  6 2017 zaitor@opensuse.org
- Update to version 0.17.7:
  + Major changes:
  - Fix licensing in OAuth2 files (they were mistakenly declared
    as GPLv3+; they’re actually LGPLv2.1+).
  - More Google Drive fixes and tests.
  - Documentation improvements (including bumping the gtk-doc
    dependency to 1.25).
  - Google Calendar parsing fixes.
  - Pagination fixes for more modern APIs (Calendar, Documents,
    Tasks, YouTube).
  - Pagination support in demo programs.
  - Add a demo program for Google Tasks.
  - Fix Google Calendar query parameters for v3 of the API.
  - Disable PicasaWeb tests as PicasaWeb server is now mostly
    read-only.
  - Deprecate Freebase service as Freebase server is now
    shutdown.
  + API changes:
  - Add GDataDocumentsEntry:file-size.
  - Add gdata_parsable_get_content_type().
  - Add GDataFeed:next-page-token.
  - Deprecate GDataCalendarQuery:recurrence-expansion-start.
  - Deprecate GDataCalendarQuery:recurrence-expansion-end.
  - Deprecate GDataCalendarQuery:sort-order.
  - Deprecate everything to do with GDataFreebase*.
  + Bugs fixed: bgo#684920, bgo#772756, bgo#773057, bgo#774179,
    bgo#777980, bgo#775813.
  + Updated translations.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 0.17.6:
  + Minor test case fixes.
  + Fix a download crash on zero-length files.
  + Bugs fixed: bgo#768278, bgo#768363, bgo#768282, bgo#769727.
  + Updated translations.
* Thu Jun 30 2016 zaitor@opensuse.org
- Update to version 0.17.5:
  + Major changes:
  - Google Drive documentation and test fixes.
  - Minor memory leak fixes.
  - Update autogen.sh to latest GNOME recommendations, fixing
    builddir ≠ srcdir.
  + Bugs fixed: bgo#684920, bgo#759180, bgo#767784, bgo#767785.
  + Updated translations.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Sun Dec 13 2015 zaitor@opensuse.org
- Update to version 0.17.4:
  + Major changes:
  - Download stream data corruption fixes and fixes to content
    length calculation.
  - Fix symbol exporting on OS X.
  - Fix copying and deleting documents in Google Drive.
  - Fix folder creation in Google Drive.
  - Fix metadata-only uploads in Google Drive.
  - Fix searching by title in Google Drive.
  + API changes: Remove a couple of incorrect GIR annotations.
  + Bugs fixed: bgo#755976, bgo#754821, bgo#758119, bgo#684920,
    bgo#758524.
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 0.17.3:
  + Major changes:
  - More Google Drive improvements
  - A few memory leak fixes and improvements in the unit tests
  + API changes:
  - Soft API break for gdata_service_insert_entry() when creating
    Google Drive folders — you must now use
    gdata_documents_service_add_entry_to_folder() due to changes
    on the server API (see bgo#684920).
  - Remove two unused symbols from the export list; these were
    never intended to be public API:
    . gdata_freebase_result_error_get_type
    . gdata_freebase_result_error_quark
  + Bugs fixed: bgo#684920, bgo#754821.
  + Updated translations.
* Sun Jul 12 2015 zaitor@opensuse.org
- Update to version 0.17.2:
  + Major changes:
  - More Google Drive API porting
  - Port from v2 to v3 of the Calendar API
  - Update and re-enable a lot of unit tests (streams, youtube,
    freebase, calendar).
  - Add calendar-cli demo
  - Port to use installed-tests; this adds
  - -enable-always-build-tests and --enable-installed-tests
    configure options.
  - Port to autoconf-archive macros and add an implicit
    build-time dependency on autoconf-archive.
  - Allow applications to store and restore the refresh token for
    a GDataOAuth2Authorizer to avoid re-authenticating on each
    startup.
  - Bump libuhttpmock dependency to 0.5.0.
  + API changes:
  - Add gdata_calendar_service_insert_calendar_event(),
    gdata_calendar_service_insert_calendar_event_async()
  - Deprecate GDataCalendarCalendar:times-cleaned,
    gdata_calendar_calendar_get_times_cleaned(),
    GDataCalendarCalendar:edited,
    gdata_calendar_calendar_get_edited().
  - Deprecate GDataCalendarFeed:timezone,
    gdata_calendar_feed_get_timezone(),
    GDataCalendarFeed:times-cleaned,
    gdata_calendar_feed_get_times_cleaned().
  - Add GDataAccessHandlerIface.get_rules as a virtual method
    backing gdata_access_handler_get_rules().
  - Add GDataCalendarAccessRule
  - Add GDataDocumentsAccessRule
  - Add gdata_oauth2_authorizer_dup_refresh_token(),
    gdata_oauth2_authorizer_set_refresh_token()
  - Add GDataBatchable.is_supported virtual function
  + Bugs fixed: bgo#684920, bgo#664353, bgo#750335, bgo#750480,
    bgo#750395, bgo#750746, bgo#751782, bgo#750914.
  + Updated translations.
- Also bump version in baselib.conf, that was missed on last
  update.
* Fri Apr 24 2015 zaitor@opensuse.org
- Update to version 0.17.1:
  + Correctly increment LT version.
- Changes from version 0.17.0:
  + Major changes:
  - Port from v2 to v3 of the YouTube API — your client’s
    developer key may stop working due to never being configured
    for v3; refresh it here:
    https://developers.google.com/youtube/registering_an_application
  - Port from the Google Docs API to the Google Drive API (v2) —
    the same libgdata APIs should continue to work unchanged.
  - Both the YouTube and Drive API ports are not thoroughly
    tested, and a number of unit tests have been disabled
    temporarily; code quality will be ramped up again in
    subsequent releases.
  - Add support for OAuth 2.0 authorisation.
  - Commit to API and ABI stability.
  - Add --disable-tests configure flag to skip building tests.
  - Various improvements to the unit tests.
  - Fix pagination handling in Google Docs.
  - Add demo applications for Google Docs and YouTube.
  - Various Freebase fixes, including a huge number of new tests
    and authentication fixes.
  - Various JSON parser fixes.
  - Note that the Calendar v2 API has now been withdrawn; there
    has not been enough time to port libgdata to version 3
    (ongoing: bgo#664353), but clients can (and should,
    regardless) use the CalDAV API provided by Google Calendar.
  + API changes:
  - Please see /usr/share/doc/packages/libgdata%%{_sover}/NEWS.
  + Bugs fixed:
  - bgo#646285, bgo#657539, bgo#739395, bgo#737799, bgo#739956,
    bgo#741345, bgo#737539, bgo#737936, bgo#737540, bgo#737541,
    bgo#742472, bgo#742473, bgo#687597, bgo#684920.
  + Updated translations.
- Bump soname following upstream changes.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 0.16.1:
  + Major changes:
  - Add a --disable-tests configure option to build without
    uhttpmock.
  - Remove downstream fix for ISO 8601 dates which was breaking
    Contacts.
  - Various fixes for the Google Tasks service.
  + Bugs fixed: bgo#739395, bgo#737799.
  + Updated translations.
* Thu Sep 18 2014 dimstar@opensuse.org
- Update to version 0.16.0:
  + Major changes:
  - Update date parsing to handle recent changes in Google’s
    servers.
  - Support ACLs with keys (e.g. for link-only sharing of
    documents).
  - Add gzip encoding support for network packet compression.
  - Support for libsoup ≥ 2.47.3 (but the dependency has not been
    bumped).
  - Basic test suite for the Google Tasks service.
  - Fix mutex warnings with new GLib versions.
  + Bugs fixed:
  - bgo#732809: evolution-3.12.3: cannot edit google contact due
    to invalid format of timestamp.
  - bgo#734863: Google contacts without email address block
    search/autocomplete.
  - bgo#690628: <gAcl:withKey/> element Not Handled by libgdata.
  - bgo#703192: The global log handler interferes with other
    application.
  - bgo#666623: Add gzip encoding support.
  + Updated translations.
* Sat Aug  9 2014 dimstar@opensuse.org
- Update to version 0.15.2:
  + Support PicasaWeb in the GOA authoriser.
  + Fix a data corruption bug in the downloads/uploads code.
  + Bugs fixed:
  - bgo#731269: Wrong scope information in authorization domain.
  - bgo#731949: Memory leak from gdata_parser_int64_to_iso8601().
  - bgo#731946: Removing a task result in error, but succeeds.
  - bgo#732890: Refresh authoriser on receiving
    SOUP_STATUS_NOT_FOUND.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 0.15.1:
  + Add a Freebase service and demo.
  + Various minor fixes to make libgdata compile without Coverity
    errors.
  + Bugs fixed: bgo#707477, bgo#725827, bgo#726486.
  + Updated translations.
* Fri Dec 20 2013 dimstar@opensuse.org
- Update to version 0.15.0:
  + Major changes:
  - Add JSON support and a Google Tasks service.
  - Add support for GProxyResolver proxies.
  - Fix build with recent gnome-common versions.
  - Fix build and installed header files for C++.
  - Remove deprecated function calls.
  - Fix compilation with -fstrict-aliasing.
  - Port local tests to use libuhttpmock (which is a new
    dependency).
  + Various API changes (see documentation).
  + Bugs fixed: bgo#712565, bgo#719647.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) and pkgconfig(libuhttpmock-0.0)
  BuildRequires: new dependencies.
- Drop pkgconfig(libsoup-gnome-2.4) BuildRequires: no longer
  required.
- Bump _sover to 19, following upstreams soname change (also in
  baselibs.conf).
* Thu Dec 19 2013 zaitor@opensuse.org
- Update to version 0.14.1:
  + Fix build with recent gnome-common versions.
  + Fix build and installed header files for C++.
  + Remove deprecated function calls.
  + Fix compilation with -fstrict-aliasing.
  + Bugs fixed: bgo#712565, bgo#719647.
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Thu Aug 29 2013 RBrownCCB@opensuse.org
- Update to version 0.14.0:
  + Updated translations.
* Fri Aug  2 2013 dimstar@opensuse.org
- Update to version 0.13.4:
  + Fixes to request cancellation and progress notification.
  + Fix tests to be more reliable in the face of distributed system
    non-synchronisation.
  + Add support for running tests offline using stored HTTP request
    traces.
  + Various API changes.
  + Bugs fixed: bgo#627895, bgo#703192, bgo#705266.
  + Updated translations.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 0.13.3:
  + Fix dependencies in pkg-config file
  + Add OAuth 2.0 support to the GOA authoriser
  + Fix some licencing inconsistencies (libgdata is entirely
    licenced under LGPLv2.1+)
  + Add support for PDF documents in Google Documents.
  + Add in-tree Vala bindings.
  + Bugs fixed: bgo#685464, bgo#685289, bgo#690281, bgo#690225,
    bgo#690656, bgo#693855, bgo#693958, bgo#693865, bgo#694415.
  + Updated translations.
* Mon Oct  1 2012 dimstar@opensuse.org
- Update to version 0.13.2:
  + Expand the documentation and add more examples
  + Explicitly check for libxml2 in configure
  + Port code coverage support to use gnome-common
  + Bugs fixed: bgo#683209
  + Updated translations.
* Sat Jul 28 2012 dimstar@opensuse.org
- Update to version 0.13.1:
  + Major changes:
  - Add support for Google Drawings
  - Fix some of the test suite
  - Add support for copying Google documents
  - Moved GOA authoriser from EDS/GNOME Documents into libgdata
  - Remove libgnome-keyring dependency in favour of libgcr-base
  + Various API changes
  + Bugs fixed: bgo#607270, bgo#633548, bgo#656970, bgo#656976,
    bgo#679072, bgo#679867
  + Updated translations.
- Add pkgconfig(goa-1.0) BuildRequires: new dependency.
- Replace plgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(gcr-base-3), following upstreams port to gcr.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 0.13.0:
  + Major changes:
  - Bump GLib dependency to 2.31.0 in order to use its new
    threading primitives
  - Add basic support for resumable uploads to GDataUploadStream
    (bgo#607272)
  - Update support for Google Documents to v3 of the API
  - Add support for arbitrary file uploads to Google Documents
    (using GDataDocumentsDocument), and document conversion on
    upload (using GDataDocumentsUploadQuery)
  + Various API changes
  + Bugs fixed: bgo#588714, bgo#593537, bgo#607616, bgo#656971.
  + Updated translations.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 0.12.0:
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Mon Mar 12 2012 dimstar@opensuse.org
- Update to version 0.11.1:
  + bgo#667577: fix introspection for srcdir != builddir builds.
  + bgo#668365: libgdata 0.10.x link error because of exported
    symbols that don't exist.
  + bgo#671535: Security issue in libgdata: Validate SSL
    certificates for all connections
  + Updated translations.
* Wed Dec 21 2011 vuntz@opensuse.org
- Update to version 0.11.0:
  + Major changes:
  - Added version checking macros.
  - Ported scrapbook demo to GtkGrid.
  - Added a LIBGDATA_DISABLE_DEPRECATED macro for disabling
    deprecated API in headers.
  - Sensitive details (passwords, auth. tokens, etc.) are now
    redacted from logs unless LIBGDATA_DEBUG=4 is set.
  - Sensitive details are also now stored in non-pageable memory
    as much as possible to reduce the risk of them being leaked.
  - Use GHmac instead of liboauth's HMAC.
  - Use the new GLib threading API iff compiled with GLib ≥
    2.31.0.
  + Merge changes from version 0.10.1.
  + API additions and deprecations (see NEWS).
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add pkgconfig(gnome-keyring-1) BuildRequires: new dependency.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GData-0_0 subpackage.
- Add typelib-1_0-GData-0_0 Requires to devel subpackage.
* Thu Sep 15 2011 vuntz@opensuse.org
- Update to version 0.10.1:
  + Bugs fixed: bgo#659016.
  + Updated translations.
* Sat Aug 20 2011 dimstar@opensuse.org
- Update to version 0.10.0:
  + Major changes:
  - Added support for comments to YouTube and PicasaWeb
  - Added a "scrapbook" demo application
  - Added lots of cancellation tests
  + API additions (see NEWS).
  + Bugs fixed: bgo#618587, bgo#598752, bgo#647882, bgo#628069,
    bgo#656529, bgo#633364.
  + Updated translations.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 0.9.1:
  + Major changes:
  - Added GDestroyNotify parameters to query-type methods so that
    they're properly introspectable, breaking API
  - Fixed seeking in GDataDownloadStream
  - Made the tests individually idempotent, so the test suites
    should be less of a tangled mess now
  - Fixed uploading to non-default PicasaWeb albums
  - Fixed GDataAuthorizer to re-process requests after
    refreshing, involving a slight change to the semantics of
    GDataAuthorizer (see bgo#653535)
  - Ensure that Google Contacts uses HTTPS for everything
  - Fixed the IDs used for Google Documents so that deleting
    documents now consistently works, even when they're in
    folders
  + API changes (see NEWS).
  + Bugs fixed: bgo#649728, bgo#639405, bgo#637664, bgo#633359,
    bgo#653535, bgo#653530, bgo#653224.
  + Updated translations.
- Bump _sover define from 11 to 13, following library soversion
  bump. Note that this results in renaming libgdata11 to
  libgdata13.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 0.9.0:
  + Major changes:
  - Use HTTPS for all requests
  - Some minor parsing fixes
  - Fixed some nasty threading/cancellation problems
  - Removed the old authentication API in favour of a more
    extensible, flexible one based on a GDataAuthorizer
    interface:
    . ClientLogin is now handled by GDataClientLoginAuthorizer
    . OAuth 1.0 support has been added with GDataOAuth1Authorizer
  - Added a dependency on liboauth ≥ 0.9.4
  - Introspection annotation improvements
  - Removed some outdated contact photo API
  + Various API changes (that are really breaking API).
  + Bugs fixed: bgo#642983, bgo#644940, bgo#644946, bgo#639610,
    bgo#648058, bgo#650835.
  + Updated translations.
- Add pkgconfig(oauth) BuildRequires.
- Remove explicit Requires for glib2-devel, libsoup-devel,
  libxml2-devel from devel subpackage.
- Add Url tag.
* Wed May  4 2011 vuntz@opensuse.org
- Update to version 0.8.1:
  + Fix some gtk-doc issues (including bgo#642983)
  + Other minor fixes to the parsing code and test suite
  + Updated translations.
* Thu Mar  3 2011 vuntz@opensuse.org
- Also update baselibs.conf after library version change.
- Change BuildRequires to pkgconfig() ones:
  + old ones: glib2-devel, libsoup-devel.
  + pkgconfig() ones: gio-2.0, libsoup-2.4, libsoup-gnome-2.4,
    libxml-2.0.
- Add pkgconfig(gdk-pixbuf-2.0) BuildRequires, which enables
  optional features.
* Thu Feb 24 2011 fcrozat@novell.com
- Update to version 0.8.0:
  + Major changes:
  - Added async counterparts to all remaining blocking methods
  - Added various cancellation tests to the test suite
  - Many fixes and improvements for cancellation of various
    operations
  - Fixed many race conditions in authentication and
    cancellation of operations
  - Removed the separate youtube-user property for YouTube
    authentication
  - Fixed attribute escaping across all of libgdata
  - Removed some deprecated PicasaWeb properties (file clients
    and positions)
  - Switched to stream-based downloading for all download
    operations
  - Tidied up (i.e. broke) the Documents service API a lot
  - Fixed several minor and major memory leaks
  - Ensured that batch operations' callbacks are always called,
    even if the entire batch operation errors out
  - Bumped our gdk-pixbuf dependency to 2.14
  - Fixed all the XML comparison tests in light of an invalid
    assumption we made about hash table ordering being broken
  - Added GeoRSS support to YouTube videos
  - Overhauled download and upload streams, fixing many race
    conditions and deadlocks and adding some test cases
  - Added support for flushing GDataUploadStream instances
  + Bugs fixed: bgo#607620, bgo#635959, bgo#635736, bgo#634033,
    bgo#635335, bgo#631033, bgo#633363, bgo#594814, bgo#637036,
    bgo#579885.
  + Updated translations.
- Changes from version 0.7.0:
  + Major changes:
  - Improved and updated introspection support and annotations
    for gobject-introspection >= 0.9.7
  - Added support for service localisation
    using gdata_service_set_locale()
  - Added support for listing video categories from YouTube
  - Tidied up object comparison using a new GDataComparable
    interface instead of lots of *_compare() methods
  - Added batch operation support and implemented it for the
    Contacts, YouTube, Calendar and Documents services
  - Fixed ID projection issues with Contact entries
  - Added support for alerting the user of account migration
    with GDATA_AUTHENTICATION_ERROR_ACCOUNT_MIGRATED
  - Added support for a --no-internet option to the tests, so
    that more of the test suite can be run automatically without
    an internet connection
  - Split handling of entries with inline content from external
    content (using the new gdata_entry_get_content_uri())
  - Rearranged Documents classes so that instantiable entries
    are now subclasses of a new GDataDocumentsDocument, which
    handles downloading of document files
  - Tightened up URI escaping
  - Switched to depending on only gdk-pixbuf instead of the
    whole of GDK, since we only (optionally) use GdkPixbuf for
    the test suite
  - Tightened up attribute escaping
  - Switched from GTimeVal to gint64 for representing UNIX
    timestamps
  - Switched to using upstream gettext instead of glib-gettext
  - Added support for manipulating Contact groups
  + Bugs fixed: bgo#616222, bgo#579885, bgo#618584, bgo#615721,
    bgo#618586, bgo#579169, bgo#624142, bgo#624141, bgo#630350.
  + Updated translations.
- Rename libgdata7 to libgdata11 following library version change.
* Thu Feb 24 2011 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Dec 14 2010 vuntz@opensuse.org
- Update to version 0.6.6:
  + Major changes:
  - Fixed attribute escaping for several elements
  - Fixed asynchronous authentication success notification
  - Various small fixes to the core, YouTube and Documents
    services
  - Fixed many small and large memory leaks
  - Fixed the XML comparisons in the test suite re. changes to
    GHashTable in GLib master
  + Bugs fixed:
  - bgo#630350: Email address cannot contain name
  - bgo#635736: Asynchronous authentication tests broken
* Thu Sep 30 2010 vuntz@opensuse.org
- Update to version 0.6.5:
  + Fixed the introspection build with gobject-introspection >=
    0.9.7 and bumped our dependency to match
  + Added a lot of missing introspection annotations
  + Fixed a few small leaks
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Wed Sep  1 2010 vuntz@opensuse.org
- Drop gir-repository BuildRequires: the introspection files that
  were needed from there are now directly with the appropriate
  libraries.
* Mon Aug 30 2010 vuntz@opensuse.org
- Add baselibs.conf.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 0.6.4:
  + Major changes:
  - Fixed the behaviour of gdata_entry_get_id() for
    GDataPicasaWebAlbum and GDataPicasaWebFile, which was
    previously *broken*
    Use gdata_picasaweb_album_get_id() and
    gdata_picasaweb_file_get_id() for the equivalent results now
  - Don't send ETags if a query is modified since it was last
    used; this improves libgdata's behaviour for programs which
    re-use GDataQuery instances
  - Lots of documentation fixes and improvements
  - Added missing #includes to gdata.h
  - Improved error reporting about network and proxy problems
  + API changes:
  - Added GDataPicasaWebAlbum:album-id,
    gdata_picasaweb_album_get_id(), GDataPicasaWebFile:file-id
    and gdata_picasaweb_file_get_id()
  - Fix the value returned by gdata_entry_get_id() for
    GDataPicasaWebAlbum and GDataPicasaWebFile; it is now a full
    URI
  + Bugs fixed:
  - bgo#613529 - Sending ETag with modified query
* Sat Mar 20 2010 dimstar@opensuse.org
- Update to version 0.6.3:
  + Major changes:
  - Contacts' names can now be set as an entire GDataGDName,
    rather than piecemeal
  - Added the kind category to GDataContactsContact on init
  + API changes:
  - Added gdata_contacts_contact_set_name and made
    GDataContactsContact:name writeable
  - Setters in GDataGDPostalAddress no longer accept empty
    strings (only NULL or a non-empty string)
  + Updated translations.
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.6.2:
  + Fixed introspection build for machines without a system-wide
    libtool. bgo#610273
  + Updated translations.
* Tue Feb 16 2010 vuntz@opensuse.org
- Update to version 0.6.1:
  + Fixed introspection build for previously-non-installed
    libgdata. bgo#610007
  + Updated translations.
* Sun Feb 14 2010 vuntz@opensuse.org
- Update to version 0.6.0:
  + Major changes:
  - Added feed icon support
  - Added support for querying for user information on the
    PicasaWeb service
  - Added some code examples to the documentation
  - Ensured UTF-8 is supported correctly everywhere
  - Added GObject introspection support (GData-0.0.gir)
  - Added a download API for PicasaWeb images and thumbnails
  - Added an asynchronous PicasaWeb upload API
  - Reorganised the build system to use non-recursive automake
  - Added gcov support and consequently improved test coverage
    somewhat
  - Ensured HTTPS requests are used wherever possible, unless the
    LIBGDATA_FORCE_HTTP environment variable is set
  - Modified memory management to consistently use the GLib
    memory manager
  - Consolidated generic API errors to
    GDATA_SERVICE_ERROR_PROTOCOL_ERROR
  + Many API additions, and a few API changes (see NEWS for
    details)
  + Bugs fixed:
  - bgo#598910 — Timestamp bug
  - bgo#598893 — gdata_picasaweb_album_new doesn't set a valid
    visibility
  - bgo#599140 — Have albums initialise date to now by default
  - bgo#589858 — Handle gphoto XML elements found in 'GDataFeed'
  - bgo#602156 — GDataUploadStream should close GOutputStream on
    dispose
  - bgo#598748 — *_download_document prevents non-overwriting
    saving into directories
  - bgo#597248, bgo#598746, bgo#598912, bgo#598913, bgo#598649,
    bgo#600262, bgo#604313, bgo#601919, bgo#607607
- Add gir-repository, gobject-introspection-devel BuildRequires.
- Rename libgdata6 to libgdata7, following soname version bump.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 0.5.1:
  + Major changes:
  - Fix up Unicode support in queries
  + Bugs fixed:
  - bgo#598746 — gdata_picasaweb_query_set_image_size
    documentation fix
  - bgo#598910 — Timestamp bug
  - bgo#598912 — Test data was changed by my mucking around with
    comments
  - bgo#598893 — gdata_picasaweb_album_new doesn't set a valid
    visibility
  - bgo#602156 — GDataUploadStream should close GOutputStream on
    dispose
- Changes from version 0.5.0:
  + Major changes:
  - Added Exif support for PicasaWeb files
  - Added the ability to query single Google Documents files
  - Errors are now logged in the "libgdata" domain
  - Added GeoRSS support for PicasaWeb files and albums
  - Optimisation to the XML output functions
  - Added streaming download and upload support using
    GDataDownloadStream and GDataUploadStream
  - Added support for silent building with AM_SILENT_RULES
  - Updated the GData namespace to version 3, improving name and
    address support
  + Many API additions, and a few API changes (see NEWS for
    details)
  + Bugs fixed:
  - bgo#589265 – Crash on query error
  - bgo#589545 – *_download_document(): let the client decide
    where to download
  - bgo#589201 – Add EXIF support for PicasaWeb image files
  - bgo#589850 – gdata_picasaweb_album_get_timestamp() returns
    date in 1970!
  - bgo#590345 – <gd:deleted> handling in GDataDocumentsEntry
  - bgo#589855 – Obsolete <rights> not handled in
    GDataPicasaWebAlbum parse_xml()
  - bgo#590341 – Allow querying of single documents
  - bgo#590132 – Unhandled XML for georss
  - bgo#590568 – Crash on querying inside a folder
  - bgo#591966 — Can't query single spreadsheets
  - bgo#591974 — remove_document_from_folder moves documents to
    the trash
  - bgo#591691 — Getting a feed containing PDF documents returns
    NULL
  - bgo#592124 — G_LOG_DOMAIN not set for subdirectories
  - bgo#592845 — Undefined symbol:
    gdata_picasaweb_query_new_with_limits
  - bgo#593239 — Use GDataUploadStream for uploading files
  - bgo#593336 — Query parameter "q=..." isn't valid for album
    kinds
  + Updated translations.
- Rename libgdata5 to libgdata6, following soname change.
* Mon Aug  3 2009 vuntz@novell.com
- Remove Obsoletes for libgdata3 and libgdata4.
- Drop libgdata-rpmlintrc as it's not needed anymore.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 0.4.0:
  + Major changes:
  - Added comparison functions for all small XML elements (such
    as GDataLink and friends)
  - Added GDataContactsContact photo support
  - Translatable strings are now even clearer, and all have
    translator comments
  - Fixed a number of locale-dependent bugs
  - Converted small XML element structs to full GObjects
  - Added a PicasaWeb service
  - Fixed more licencing issues (libgdata is licenced under
    LGPLv2.1+)
  - Required link relation types to be full URIs
  - Added a Google Documents service
  + API changes:
  - Added gdata_contacts_contact_get_extended_properties
  - Added *_compare
  - Added GDataContactsContact:has-photo,
    gdata_contacts_contact_has_photo,
    gdata_contacts_contact_get_photo,
    gdata_contacts_contact_set_photo
  - Converted GDataAuthor, GDataCategory, GDataLink,
    GDataGenerator to GObjects (removed *_free functions and
    added mandatory field accessors)
  - Converted GDataGDEmailAddress, GDataGDFeedLink,
    GDataGDIMAddress, GDataGDOrganization, GDataGDPhoneNumber,
    GDataGDPostalAddress, GDataGDRating, GDataGDWhen,
    GDataGDReminder, GDataGDWhere, GDataGDWho to GObjects
    (removed *_free functions and added mandatory field
    accessors)
  - Converted GDataMediaCategory, GDataMediaContent,
    GDataMediaCredit, GDataMediaRating, GDataMediaRestriction,
    GDataMediaThumbnail to GObjects
  - (removed *_free functions and added mandatory field
    accessors)
  - Removed gdata_media_thumbnail_parse_time,
    gdata_media_thumbnail_build_time
  - Converted GDataYouTubeState to GObject (removed
    gdata_youtube_state_free and added mandatory field accessors)
  - Added GDataYouTubeControl
  - Added PicasaWeb service API
  - Removed gdata_entry_new_from_xml, other *_new_from_xml
    functions, gdata_entry_get_xml
  - Added gdata_parsable_new_from_xml, gdata_parsable_get_xml
  - Removed GDATA_PARSER_ERROR_UNHANDLED_XML_ELEMENT parser error
  - Added GDataParsableClass->element_name,
    GDataParsableClass->element_namespace
  - Added GDATA_LINK_ALTERNATE, GDATA_LINK_EDIT,
    GDATA_LINK_EDIT_MEDIA, GDATA_LINK_ENCLOSURE,
    GDATA_LINK_RELATED, GDATA_LINK_SELF, GDATA_LINK_VIA for use
    with gdata_entry_look_up_link
  - Added gdata_contacts_service_update_contact
  - Added gdata_youtube_service_query_single_video,
    gdata_youtube_service_query_single_video_async,
    gdata_youtube_service_query_single_video_finish
  - Added gdata_youtube_video_get_video_id_from_uri
  - Added GDataYouTubeAspectRatio,
    gdata_youtube_video_get_aspect_ratio,
    gdata_youtube_video_set_aspect_ratio
  - Added Google Documents service API
  - Added gdata_contacts_contact_remove_all_email_addresses,
    gdata_contacts_contact_remove_all_im_addresses,
    gdata_contacts_contact_remove_all_postal_addresses,
    gdata_contacts_contact_remove_all_phone_numbers,
    gdata_contacts_contact_remove_all_organizations
  + Bugs fixed:
  - bgo#584417 - Strings are not properly formed for localisation
  - bgo#584737 - String parsing is locale-sensitive
  - bgo#579170 - Eliminate gdata_parser_error_unhandled_element
  - bgo#587277 - Some files are GPLv3 but license is LGPLv2.1?
  - bgo#588052 - Parse the yt:aspectratio tag
  - bgo#587073 - Add Google Documents service
  - bgo#588995 - float radix character depends on LC_NUMERIC, but
    Google wants "."
  + Updated translations.
- Rename package to libgdata5, and Obsoletes libgdata4.
* Wed May 27 2009 vuntz@novell.com
- Update to version 0.3.0:
  + Major changes:
  - Empty (but present) entry titles are now set to an empty
    string, rather than NULL
  - GDataCalendarEvent has basic recurrence support
  - Optional GNOME support has been added for automagic proxy
    configuration (depends on libsoup-gnome-2.4)
  - Deprecated libsoup API has been removed, bumping the
    requirement to 2.26.1
  - Translation comments and some translatable strings have been
    made clearer
  - Default error handling has been improved
  - More async versions of functions have been added
  - The XML output of GDataCalendarCalendar has been completed
  - GDataYouTubeVideo now has support for recorded times and
    comment feed links
  - Added a GDataYouTubeQuery class
  - Access control list (ACL) support, implemented on
    GDataCalendarCalendar
  - Abstract XML parsing into GDataParsable to allow GDataFeed to
    be overridden
  - Added a GDataCalendarFeed class to deal with
    calendar-specific properties
  + API changes:
  - Added GDataCalendarEvent:recurrence,
    gdata_calendar_event_get_recurrence,
    gdata_calendar_event_set_recurrence
  - Added GDataCalendarEvent:original-event-id,
    GDataCalendarEvent:original-event-uri,
    gdata_calendar_event_get_original_event_details
  - Added gdata_calendar_event_is_exception
  - Added GDATA_SERVICE_ERROR_NOT_FOUND,
    GDATA_SERVICE_ERROR_CONFLICT
  - Changed GDataServiceClass->parse_error_response
  - Added gdata_service_insert_entry_async,
    gdata_service_insert_entry_finish
  - Added gdata_service_update_entry_async,
    gdata_service_update_entry_finish
  - Added gdata_service_delete_entry_async,
    gdata_service_delete_entry_finish
  - Added gdata_color_to_hexadecimal
  - Added GDataYouTubeVideo:comments-feed-link,
    gdata_youtube_video_get_comments_feed_link
  - Added GDataYouTubeVideo:recorded,
    gdata_youtube_video_get_recorded,
    gdata_youtube_video_set_recorded
  - Added read_only parameter to gdata_gd_feed_link_new and
    member to GDataGDFeedLink
  - Added GDataYouTubeQuery
  - Added GDataAccessHandler, GDataAccessRule
  - Added GDATA_SERVICE_ERROR_FORBIDDEN
  - Added GDataParsable
  - Changed GDataEntry to extend GDataParsable, rather than
    GObject
  - Removed GDataEntry->parse_xml
  - Changed GDataFeed to extend GDataParsable, rather than
    GObject
  - Added GDataCalendarFeed
  - Added GDataServiceClass->feed_type
  + Bugs fixed:
  - bgo#582026 – Access Control List functionality
  - bgo#578367 – Add support for YouTube-specific query
    parameters
  - bgo#581706 – translation issues
  - bgo#580330 – Rejects empty entry titles
  + Updated translations.
- Rename package to libgdata4, and Obsoletes libgdata3.
- Add libgdata-rpmlintrc.
* Sun May 24 2009 vuntz@novell.com
- Initial package.
